From: wysochanski@sourceware.org <wysochanski@sourceware.org>
To: lvm-devel@redhat.com
Subject: LVM2/tools lvcreate.c
Date: 26 Jul 2009 02:31:42 -0000 [thread overview]
Message-ID: <20090726023142.15936.qmail@sourceware.org> (raw)
CVSROOT: /cvs/lvm2
Module name: LVM2
Changes by: wysochanski at sourceware.org 2009-07-26 02:31:42
Modified files:
tools : lvcreate.c
Log message:
Move percent_t from struct lvcreate_params to struct lvcreate_cmdline_params.
Create a new structure, lvcreate_cmdline_params, to store parameters only
relevant for the cmdline, not the library call to lvcreate.
Should be no functional change.
Author: Dave Wysochanski <dwysocha@redhat.com>
Patches:
http://sourceware.org/cgi-bin/cvsweb.cgi/LVM2/tools/lvcreate.c.diff?cvsroot=lvm2&r1=1.201&r2=1.202
--- LVM2/tools/lvcreate.c 2009/07/26 02:31:18 1.201
+++ LVM2/tools/lvcreate.c 2009/07/26 02:31:41 1.202
@@ -18,6 +18,10 @@
#include <fcntl.h>
+struct lvcreate_cmdline_params {
+ percent_t percent;
+};
+
/* FIXME: refactor and reduce the size of this struct! */
struct lvcreate_params {
/* flags */
@@ -46,7 +50,6 @@
uint64_t size;
uint32_t voriginextents;
uint64_t voriginsize;
- percent_t percent;
struct dm_list *pvh;
uint32_t permission;
@@ -163,7 +166,8 @@
* need the vg.
*/
static int _update_extents_params(struct volume_group *vg,
- struct lvcreate_params *lp)
+ struct lvcreate_params *lp,
+ struct lvcreate_cmdline_params *lcp)
{
uint32_t pv_extent_count;
@@ -178,7 +182,7 @@
return_0;
/*
* Create the pv list before we parse lp->percent - might be
* PERCENT_PVSs
*/
if (lp->pv_count) {
@@ -188,7 +192,7 @@
} else
lp->pvh = &vg->pvs;
- switch(lp->percent) {
+ switch(lcp->percent) {
case PERCENT_VG:
lp->extents = lp->extents * vg->extent_count / 100;
break;
@@ -215,6 +219,7 @@
}
static int _read_size_params(struct lvcreate_params *lp,
+ struct lvcreate_cmdline_params *lcp,
struct cmd_context *cmd)
{
if (arg_count(cmd, extents_ARG) + arg_count(cmd, size_ARG) != 1) {
@@ -228,7 +233,7 @@
return 0;
}
lp->extents = arg_uint_value(cmd, extents_ARG, 0);
- lp->percent = arg_percent_value(cmd, extents_ARG, PERCENT_NONE);
+ lcp->percent = arg_percent_value(cmd, extents_ARG, PERCENT_NONE);
}
/* Size returned in kilobyte units; held in sectors */
@@ -238,7 +243,7 @@
return 0;
}
lp->size = arg_uint64_value(cmd, size_ARG, UINT64_C(0));
- lp->percent = PERCENT_NONE;
+ lcp->percent = PERCENT_NONE;
}
/* Size returned in kilobyte units; held in sectors */
@@ -407,13 +412,16 @@
return 1;
}
-static int _lvcreate_params(struct lvcreate_params *lp, struct cmd_context *cmd,
+static int _lvcreate_params(struct lvcreate_params *lp,
+ struct lvcreate_cmdline_params *lcp,
+ struct cmd_context *cmd,
int argc, char **argv)
{
int contiguous;
unsigned pagesize;
memset(lp, 0, sizeof(*lp));
+ memset(lcp, 0, sizeof(*lcp));
/*
* Check selected options are compatible and determine segtype
@@ -508,7 +516,7 @@
}
if (!_lvcreate_name_params(lp, cmd, &argc, &argv) ||
- !_read_size_params(lp, cmd) ||
+ !_read_size_params(lp, lcp, cmd) ||
!_read_stripe_params(lp, cmd) ||
!_read_mirror_params(lp, cmd))
return_0;
@@ -1006,11 +1014,12 @@
{
int r = ECMD_PROCESSED;
struct lvcreate_params lp;
+ struct lvcreate_cmdline_params lcp;
struct volume_group *vg;
memset(&lp, 0, sizeof(lp));
- if (!_lvcreate_params(&lp, cmd, argc, argv))
+ if (!_lvcreate_params(&lp, &lcp, cmd, argc, argv))
return EINVALID_CMD_LINE;
log_verbose("Finding volume group \"%s\"", lp.vg_name);
@@ -1020,7 +1029,7 @@
return ECMD_FAILED;
}
- if (!_update_extents_params(vg, &lp))
+ if (!_update_extents_params(vg, &lp, &lcp))
return ECMD_FAILED;
if (!_lvcreate(vg, &lp))
next reply other threads:[~2009-07-26 2:31 UTC|newest]
Thread overview: 24+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-07-26 2:31 wysochanski [this message]
-- strict thread matches above, loose matches on Subject: below --
2012-03-02 20:18 LVM2/tools lvcreate.c zkabelac
2012-02-01 1:54 agk
2011-11-10 12:40 zkabelac
2011-11-10 12:39 zkabelac
2011-09-27 12:37 agk
2011-09-07 9:25 zkabelac
2011-09-06 15:35 agk
2011-03-25 21:56 jbrassow
2010-10-25 12:05 zkabelac
2010-05-11 21:40 jbrassow
2009-07-26 2:32 wysochanski
2009-07-26 2:32 wysochanski
2009-07-26 2:32 wysochanski
2009-07-26 2:31 wysochanski
2009-07-26 2:30 wysochanski
2009-06-06 22:06 mbroz
2009-05-27 13:07 agk
2009-04-26 8:12 prajnoha
2008-07-17 15:19 wysochanski
2008-01-16 15:26 agk
2007-10-01 15:01 wysochanski
2007-09-24 13:29 wysochanski
2006-10-16 16:47 agk
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20090726023142.15936.qmail@sourceware.org \
--to=wysochanski@sourceware.org \
--cc=lvm-devel@redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -178,7 +182,7 @@
return_0;
/*
- * Create the pv list before we parse lp->percent - might be
+ * Create the pv list before we parse lcp->percent - might be
* PERCENT_PVSs
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.